function data = loadmesh(pb,name,st,tw)
  
% load data
  
  eval(['ms = pb.',name,';'])
  
  if isempty(ms)
    disp('field not defined')
    return
  end
  
  t = pb.t;
  
  if nargin==2; 
    st = 1; % factor multiplying stride in time
    tw = [min(t) max(t)]; % time window
  elseif nargin==3
    tw = [min(t) max(t)];
  end
  
  % assign position and vectors
  
  data = ms;
  
  data.x = linspace(ms.xmin,ms.xmax,ms.nx);
  data.y = linspace(ms.ymin,ms.ymax,ms.ny);
  data.z = linspace(ms.zmin,ms.zmax,ms.nz);

  mmin = find(t>=ms.tmin,1,'first');
  mmax = find(t<=ms.tmax,1,'last');

  to = t(mmin:ms.stride_t:mmax); % output times
  
  tw(1) = max(ms.tmin,tw(1));
  n = find(to>=tw(1),1,'first');
  tw(1) = to(n);

  tw(2) = min(ms.tmax,tw(2));
  n = find(to<=tw(2),1,'last');
  tw(2) = to(n);
  
  nmin = find(t>=tw(1),1,'first');
  nmax = find(t<=tw(2),1,'last');
  
  data.t = t(nmin:ms.stride_t*st:nmax);
  
  data.nt = length(data.t);
  data.tmin = min(data.t);
  data.tmax = max(data.t);
  
  % set dimensions
  
  dim = 3;
  if ms.nx==1;dim=dim-1;end
  if ms.ny==1;dim=dim-1;end
  if ms.nz==1;dim=dim-1;end

  % open file
  
  [f m] = fopen([pb.f00,'_',ms.name,'.dat'],'r',pb.endian);
  if ~isempty(m);disp(m);end
  if f==-1;return;end
  
  % skip space between data values (needed with Fortran binary data output format)

  readspace = 'fseek(f,4,0);';

  % indices of time steps to be loaded

  Nmax = length(to); % number of time steps output
  
  low = 1; high = length(to);
  for n=1:data.nt
    it(n) = find(to(low:high)==data.t(n));
    it(n) = it(n)-1+low;
    low = it(n);
  end
  
  % read data
  
  switch dim
    
   case 0
    
    eval(['data.',ms.field,' = zeros(1,data.nt);']);
    readdata = ['data.',ms.field,'(n) = fread(f,1,',pb.pre,');'];
    datasize = 1;
    
   case 1
    
    if ms.nx~=1

      eval(['data.',ms.field,' = zeros(data.nt,ms.nx);']);
      datasize = ms.nx;
      readdata = ['data.',ms.field,'(n,:) = fread(f,[ms.nx],',pb.pre,');'];
    
    elseif ms.ny~=1
      
      eval(['data.',ms.field,' = zeros(data.nt,ms.ny);']);
      readdata = ['data.',ms.field,'(n,:) = fread(f,[ms.ny],',pb.pre,');'];
      datasize = ms.ny;
    
    elseif ms.nz~=1

      eval(['data.',ms.field,' = zeros(data.nt,ms.nz);']);
      readdata = ['data.',ms.field,'(n,:) = fread(f,[ms.nz],',pb.pre,');'];
      datasize = ms.nz;
    
    end
   
   case 2

    if ms.nx==1

      eval(['data.',ms.field,' = zeros(data.nt,ms.ny,ms.nz);']);
      readdata = ['data.',ms.field,'(n,:,:) = fread(f,[ms.ny ms.nz],',pb.pre,');'];
      datasize = ms.ny*ms.nz;
    
    elseif ms.ny==1

      eval(['data.',ms.field,' = zeros(data.nt,ms.nx,ms.nz);']);
      readdata = ['data.',ms.field,'(n,:,:) = fread(f,[ms.nx ms.nz],',pb.pre,');'];
      datasize = ms.nx*ms.nz;
    
    elseif ms.nz==1

      eval(['data.',ms.field,' = zeros(data.nt,ms.nx,ms.ny);']);
      readdata = ['data.',ms.field,'(n,:,:) = fread(f,[ms.nx ms.ny],',pb.pre,');'];
      datasize = ms.nx*ms.ny;
    
    end
   
   case 3

    eval(['data.',ms.field,' = zeros(data.nt,ms.nx,ms.ny,ms.nz);']);
    readdata = ['for iz=1:ms.nz; data.',ms.field,'(n,:,:,iz) = fread(f,[ms.nx ms.ny],',pb.pre,'); end'];
    datasize = ms.nx*ms.ny*ms.nz;
  
  end

  disp(['loading ',num2str(data.nt),' time steps'])
  %it
  it_old = 0;
  %npos = 0;
  for n=1:data.nt
    nskip = it(n)-it_old-1;
    offset = (8+4*datasize)*nskip;
    fseek(f,offset,0);
    %npos = npos+nskip+1;
    %disp(['pos=',num2str(npos)])
    eval(readspace);
    eval(readdata);
    eval(readspace);
    it_old = it(n);
  end
      
  fclose(f);