! MDSBI version 3.9.10 -- Multi-Dimensional Spectral Boundary Integral Code
module mpi_routines

  use constants, only : pin,pr
  use mpi

  implicit none

  type mpi_type
     integer(pin) :: np=1,myid=0
  end type mpi_type

  integer(pin),parameter :: master=0
  integer(pin) :: MPI_REAL_PR,MPI_CPLX_PR
  real(pr) :: starttime,endtime

contains

  
  function using_mpi()

    use constants, only : zero

    implicit none

    logical :: using_mpi

    if (MPI_WTime()==zero) then
       using_mpi = .false.
    else
       using_mpi = .true.
    end if

  end function using_mpi


  subroutine start_mpi(mp)

    use constants, only : real4,real8
    
    implicit none

    type(mpi_type),intent(out) :: mp

    integer(pin) :: ierr
    
    select case(pr)
    case(real4)
       MPI_REAL_PR = MPI_REAL
       MPI_CPLX_PR = MPI_COMPLEX
    case(real8)
       MPI_REAL_PR = MPI_DOUBLE_PRECISION
       MPI_CPLX_PR = MPI_DOUBLE_COMPLEX
    end select

    call MPI_INIT(ierr)
    
    starttime = MPI_WTime()
    
    call MPI_COMM_SIZE(MPI_COMM_WORLD,mp%np,ierr)

    call MPI_COMM_RANK(MPI_COMM_WORLD,mp%myid,ierr)

  end subroutine start_mpi


  subroutine finish_mpi(mp)

    implicit none

    type(mpi_type),intent(in) :: mp

    integer(pin) :: ierr

    endtime = MPI_WTime()

    call MPI_Finalize(ierr)

    if (is_master(mp)) then
       write (6,'(a)') ''
       write (6,'(a,g20.10,a)') 'Total MPI time ',endtime-starttime,' s'
       write (6,'(a)') 'Normal termination of MPI'
    end if

  end subroutine finish_mpi


  function is_master(mp)
    
    type(mpi_type),intent(in) :: mp
    logical :: is_master
    
    is_master = (mp%myid==master)

  end function is_master


  subroutine divide1d(n,p,i,l,u)

    ! N = number of tasks
    ! P = number of processors
    ! I = rank of process (0<=i<=p-1)
    ! L = starting index
    ! U = ending index

    implicit none
    
    integer(pin),intent(in) :: n,p,i
    integer(pin),intent(out) :: l,u

    integer(pin) :: w,r,o,j
    
    w = n/p
    r = mod(n,p)
    
    if (i<p-r) then
       ! w tasks
       l =  i   *w+1
       u = (i+1)*w
    else
       ! w+1 tasks
       o = (p-r)*w
       j = i-(p-r)
       l = o+ j   *(w+1)+1
       u = o+(j+1)*(w+1)
    end if

  end subroutine divide1d


  subroutine scatterv(n,p,counts,displs)

    ! n = number of tasks
    ! p = number of processors

    implicit none
    
    integer(pin),intent(in) :: n,p
    integer(pin),dimension(0:p-1),intent(out) :: counts,displs

    integer(pin) :: w,r,i,k

    w = n/p
    r = mod(n,p)

    k = 0
    do i = 0,p-1
       if (i<p-r) then
          counts(i) = w
       else
          counts(i) = w+1
       end if
       displs(i) = k
       k = k+counts(i)
       
    end do

  end subroutine scatterv


end module mpi_routines
